@@ -3,7 +3,9 @@ from quoters.constants import CONN_URL
 
 def is_connected():
     try:
-        socket.create_connection((CONN_URL, 80))
+        sock_conn = socket.create_connection((CONN_URL, 80))
+        if(sock_conn):
+            sock_conn.close()
         return True
     except OSError:
         pass
